# hochwasserzentralen
Das Länderübergreifendes Hochwasserportal (LHP) bietet auf https://www.hochwasserzentralen.de über die hier dokumentierte API Informationen zur Hochwassersituation in Deutschland an. Betreiber des LHP sind das Bayerische Landesamt für Umwelt (LfU) und die Landesanstalt für Umwelt Baden-Württemberg (LUBW).
Die Urheberrechte an den veröffentlichten Daten liegen nach [Auskunft der Betreiber](https://www.hochwasserzentralen.de/impressum) bei der für das jeweilige Bundesland zuständigen Hochwasserzentrale bzw. beim jeweiligen Pegelbetreiber.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 0.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

```sh
pip install deutschland[hochwasserzentralen]
```

### poetry install

```sh
poetry add deutschland -E hochwasserzentralen
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

## Usage

Import the package:
```python
from deutschland import hochwasserzentralen
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
from deutschland import hochwasserzentralen
from pprint import pprint
from deutschland.hochwasserzentralen.api import default_api
from deutschland.hochwasserzentralen.model.lage_pegel import LagePegel
# Defining the host is optional and defaults to https://www.hochwasserzentralen.de
# See configuration.py for a list of all supported configuration parameters.
configuration = hochwasserzentralen.Configuration(
    host = "https://www.hochwasserzentralen.de"
)



# Enter a context with an instance of the API client
with hochwasserzentralen.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = default_api.DefaultApi(api_client)
    version = "20211130" # str | 

    try:
        # Geojson der Bundesländer
        api_response = api_instance.vhosts_geojson_bundesland_version_geojson_get(version)
        pprint(api_response)
    except hochwasserzentralen.ApiException as e:
        print("Exception when calling DefaultApi->vhosts_geojson_bundesland_version_geojson_get: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://www.hochwasserzentralen.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**vhosts_geojson_bundesland_version_geojson_get**](docs/DefaultApi.md#vhosts_geojson_bundesland_version_geojson_get) | **GET** /vhosts/geojson/bundesland.{version}.geojson | Geojson der Bundesländer
*DefaultApi* | [**webservices_get_infosbundesland_php_post**](docs/DefaultApi.md#webservices_get_infosbundesland_php_post) | **POST** /webservices/get_infosbundesland.php | Infos zu einem Bundesland.
*DefaultApi* | [**webservices_get_infospegel_php_post**](docs/DefaultApi.md#webservices_get_infospegel_php_post) | **POST** /webservices/get_infospegel.php | Infos zu einem Pegel.
*DefaultApi* | [**webservices_get_lagepegel_php_get**](docs/DefaultApi.md#webservices_get_lagepegel_php_get) | **GET** /webservices/get_lagepegel.php | Lage der Pegel mit Pegelnummern


## Documentation For Models

 - [LagePegel](docs/LagePegel.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

kontakt@bund.dev


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in hochwasserzentralen.apis and hochwasserzentralen.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from deutschland.hochwasserzentralen.api.default_api import DefaultApi`
- `from deutschland.hochwasserzentralen.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
from deutschland import hochwasserzentralen
from deutschland.hochwasserzentralen.apis import *
from deutschland.hochwasserzentralen.models import *
```

